package de.meinefirma.meinprojekt.dao;

import java.util.List;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.persistence.EntityManager;
import javax.persistence.Query;

/** Super-Klasse fuer alle DAOs */
public abstract class AbstractDao
{
   protected final EntityManager em;

   public AbstractDao() throws NamingException
   {
      em = (EntityManager) (new InitialContext()).lookup( "java:comp/env/persistence/em" );
   }

   // Erstelle neuen Eintrag:
   public <T> void createEntity( T entity )
   {
      em.persist( entity );
   }

   // Lies bestimmte Eintraege zu einer Entity-Klasse:
   @SuppressWarnings("unchecked")
   public <T> List<T> queryEntities( String namedQuery, String paramName, String paramValue )
   {
      Query query = em.createNamedQuery( namedQuery );
      query.setParameter( paramName, paramValue );
      return query.getResultList();
   }

   // Lies alle Eintraege zu einer Entity-Klasse:
   @SuppressWarnings("unchecked")
   public <T> List<T> readAllEntities( Class<T> clss )
   {
      return em.createQuery( "Select d from " + clss.getSimpleName() + " d" ).getResultList();
   }
}
