package de.meinefirma.meinprojekt.servletfilter;

import java.io.IOException;
import javax.naming.*;
import javax.persistence.*;
import javax.servlet.*;
import javax.transaction.UserTransaction;

public class JpaServletFilter implements Filter
{
   private static final ThreadLocal<EntityManager> entityManagerHolder = new ThreadLocal<>();

   @Override public void doFilter( ServletRequest requ, ServletResponse resp, FilterChain chain )
   throws IOException, ServletException
   {
      UserTransaction utx = null;
      try {
         EntityManager em = (EntityManager) (new InitialContext()).lookup( "java:comp/env/persistence/em" );
         utx = (UserTransaction) (new InitialContext()).lookup( "java:comp/UserTransaction" );
         utx.begin();
         entityManagerHolder.set( em );
         chain.doFilter( requ, resp );
         utx.commit();
      } catch( Exception ex ) {
         try { if( utx != null ) utx.rollback(); } catch( Exception e ) { /* ok */ }
         throw new ServletException( ex );
      } finally {
         entityManagerHolder.remove();
      }
   }

   public static EntityManager getEntityManager()
   {
      return entityManagerHolder.get();
   }

   @Override public void init( FilterConfig arg0 ) throws ServletException { /* nicht benoetigt */ }
   @Override public void destroy() { /* nicht benoetigt */ }
}
