package de.meinefirma.meinprojekt.dao;

import javax.persistence.EntityTransaction;
import javax.transaction.*;

/**
 * Diese Klasse implementiert die wichtigsten Methoden der beiden unterschiedlichen Transaction-Interfaces
 * "{@link javax.persistence.EntityTransaction}" und "{@link javax.transaction.UserTransaction}",
 * je nach verwendetem Konstruktor entweder in der einen oder in der anderen Variante.
 */
public class EntityOrUserTransaction
{
   private final EntityTransaction etx;
   private final UserTransaction   utx;

   // Application-managed EntityTransaction (Type "RESOURCE_LOCAL"):
   public EntityOrUserTransaction( EntityTransaction etx )
   {
      this.etx = etx;
      this.utx = null;
   }

   // JTA-verwaltete UserTransaction (Type "JTA"):
   public EntityOrUserTransaction( UserTransaction utx )
   {
      this.utx = utx;
      this.etx = null;
   }

   public void begin() throws NotSupportedException, SystemException
   {
      if( etx != null ) etx.begin();
      if( utx != null ) utx.begin();
   }

   public void commit() throws RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException
   {
      if( etx != null ) etx.commit();
      if( utx != null ) utx.commit();
   }

   public void rollback() throws SystemException
   {
      if( etx != null ) etx.rollback();
      if( utx != null ) utx.rollback();
   }
}
