package de.meinefirma.meinprojekt.servletimpl;

import java.io.*;
import java.util.List;
import javax.persistence.EntityManager;
import javax.servlet.ServletException;
import javax.servlet.http.*;
import de.meinefirma.meinprojekt.entities.MeineDaten;
import de.meinefirma.meinprojekt.servletfilter.JpaServletFilter;

public class MeinTestServlet extends HttpServlet
{
   private static final long serialVersionUID = 1L;

   @Override
   public void doGet( HttpServletRequest requ, HttpServletResponse resp )
   throws ServletException, IOException
   {
      EntityManager em   = JpaServletFilter.getEntityManager();
      String        text = requ.getParameter( "text" );
      String        r    = requ.getParameter( "r" );

      // Daten persistieren:
      if( text != null && text.trim().length() > 0 ) {
         MeineDaten dat = new MeineDaten();
         dat.setMeinText( text );
         em.persist( dat );
      } else {
         text = "BlaBlupp";
      }

      // Response starten:
      resp.setContentType( "text/html; charset=ISO-8859-1" );
      try( PrintWriter out = resp.getWriter() ) {
         if( r != null ) {
            // Nur Thread-Namen returnieren (fuer Multithreading-Test):
            out.println( "Text: " + text + ";  Server-Thread: " + Thread.currentThread().getId() +
                  ", " + Thread.currentThread().getName() );
         } else {
            // Alle gespeicherten Daten lesen und HTML-Output erzeugen (fuer Webseite):
            List<MeineDaten> datAll = readAllEntities( em, MeineDaten.class );
            out.println( "<html>" );
            out.println( "<head><title>MeinTestServlet</title></head>" );
            out.println( "<body><h2>Mein JPA-Servlet</h2>" );
            out.println( "<form method='GET' enctype='application/x-www-form-urlencoded'>" );
            out.println( "Mein Text: <input type='text' name='text' value='" + text + "' maxlength=20>" );
            out.println( "<input type='submit' value='Speichern'></form>" );
            if( datAll != null && !datAll.isEmpty() ) {
               out.println( "<table border='1' cellspacing='0' cellpadding='5'><tr><td>Id</td><td>LastUpdate</td><td>Text</td></tr>" );
               for( MeineDaten d : datAll ) {
                  out.println( "<tr><td>" + d.getId() + "</td><td>" + d.getLastUpdate() + "</td><td>" + d.getMeinText() + "</td></tr>" );
               }
               out.println( "</table>" );
            }
            out.println( "</body></html>" );
         }
      }
   }

   @SuppressWarnings("unchecked")
   public static <T> List<T> readAllEntities( EntityManager em, Class<T> clss )
   {
      return em.createQuery( "Select d from " + clss.getSimpleName() + " d" ).getResultList();
   }
}
